﻿namespace SyncMVC.Models
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Web;
    using SyncMVC.Models;
    using System.Data.SqlClient;
    using System.Data;


    public static class OrderRepository
    {
        public static IList<EditableOrder> GetAllRecords()
        {
            IList<EditableOrder> orders = (from ord in new NorthwindDataContext().Orders
                                                                  select new EditableOrder
                                                                  {
                                                                      OrderID = ord.OrderID,
                                                                      OrderDate = ord.OrderDate,
                                                                      CustomerID = ord.CustomerID,
                                                                      EmployeeID = ord.EmployeeID,
                                                                      Freight = ord.Freight,
                                                                      ShipAddress = ord.ShipAddress,
                                                                      ShipCity = ord.ShipCity,
                                                                      ShipName = ord.ShipName,
                                                                      ShipPostalCode = ord.ShipPostalCode,
                                                                      ShipRegion = ord.ShipRegion,
                                                                      ShipCountry = ord.ShipCountry
                                                                  }).ToList();
                foreach (var order in orders)
                {
                    if (order.Freight > 30)
                        order.Verified = true;
                    else
                        order.Verified = false;
                }
            
            return orders;
        }


        public static void Add(EditableOrder order)
        {
            //method triggered when add operation is performed
            SqlConnection con = new SqlConnection(@"Data Source=(LocalDB)\v11.0;AttachDbFilename=|DataDirectory|\NORTHWND.mdf;Integrated Security=True");

            SqlCommand cmd = new SqlCommand();
            cmd.CommandType = CommandType.StoredProcedure;
            cmd.CommandText = "[prc_InsertOrder]";// this stored procedure has the sql query corresponding to insert operation
            cmd.Parameters.Add(new SqlParameter("@employeeid", SqlDbType.Int)).Value = order.EmployeeID;
            cmd.Parameters.Add(new SqlParameter("@orderId", SqlDbType.Int)).Value = order.OrderID;
            cmd.Parameters.Add(new SqlParameter("@shipCity", SqlDbType.VarChar)).Value = order.ShipCity;
            cmd.Parameters.Add(new SqlParameter("@freight", SqlDbType.Int)).Value = order.Freight;
            cmd.Connection = con;
            con.Open();

            cmd.ExecuteNonQuery();// executing the insertion operation in the database using the sql query
            con.Close();
        }
        

        public static void Delete(int OrderID)
        {
            // method record when a record is deleted
            SqlConnection con = new SqlConnection(@"Data Source=(LocalDB)\v11.0;AttachDbFilename=|DataDirectory|\NORTHWND.mdf;Integrated Security=True");

            SqlCommand cmd = new SqlCommand();
            cmd.CommandType = CommandType.StoredProcedure;
            cmd.CommandText = "[prc_DeleteOrder]";// this stored procedure has the sql query corresponding to delete operation
            cmd.Parameters.Add(new SqlParameter("@orderId", SqlDbType.Int)).Value = OrderID;
            cmd.Connection = con;
            con.Open();
            cmd.ExecuteNonQuery();// executing the deletion operation in the database using the sql query
            con.Close();
        }
       

        public static void Update(EditableOrder order)
        {
            // method triggered when Update operation is performed
            SqlConnection con = new SqlConnection(@"Data Source=(LocalDB)\v11.0;AttachDbFilename=|DataDirectory|\NORTHWND.mdf;Integrated Security=True");

            SqlCommand cmd = new SqlCommand();
            cmd.CommandType = CommandType.StoredProcedure;//stored procedure is set as command type
            cmd.CommandText = "[prc_UpdateOrder]";// this stored procedure has the sql query corresponding to update operation
            cmd.Parameters.Add(new SqlParameter("@employeeid", SqlDbType.Int)).Value = order.EmployeeID;
            cmd.Parameters.Add(new SqlParameter("@shipCity", SqlDbType.VarChar)).Value = order.ShipCity;
            cmd.Parameters.Add(new SqlParameter("@orderId", SqlDbType.Int)).Value = order.OrderID;
            cmd.Parameters.Add(new SqlParameter("@freight", SqlDbType.Int)).Value = order.Freight;
            cmd.Connection = con;// sql connection is established
            con.Open();
            cmd.ExecuteNonQuery();// executing the update operation in the database using the sql query
            con.Close();
        }

        
    }
}
